@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -230,7 +230,7 @@ sub ProviderProcessRequest {
 
     # Convert charset if necessary.
     my $ContentCharset;
-    if ( $ENV{'CONTENT_TYPE'} =~ m{ \A ( .+ ) ;\s*charset= ["']{0,1} ( .+? ) ["']{0,1} (;|\z) }xmsi ) {
+    if ( $ENV{'CONTENT_TYPE'} =~ m{ \A ( .+ ) ;\s*charset\s*=\s* ["']{0,1} ( .+? ) ["']{0,1} (;|\z) }xmsi ) {
 
         # Remember content type for the response.
         $Self->{ContentType} = $1;
@@ -409,7 +409,7 @@ The HTTP code is set accordingly
 - C<500> for content syntax errors
 
     my $Result = $TransportObject->ProviderGenerateResponse(
-        Success => 1
+        Success => 1,
         Data    => { # data payload for response, optional
             ...
         },
@@ -1089,7 +1089,7 @@ sub RequesterPerformRequest {
     # Check if we have response data for the specified operation in the soap result.
     if ( !exists $Body->{$OperationResponse} ) {
         return {
-            Success => 0,
+            Success      => 0,
             ErrorMessage =>
                 "No response data found for specified operation '$OperationName'"
                 . " in soap response",
@@ -1286,42 +1286,44 @@ If entries exist that are not mentioned in sorting config,
 they will be added after the sorted entries in ascending alphanumerical order.
 
 Example:
-$Data = {
-    Key1 => 'Value',
-    Key2 => {
-        Key3 => 'Value',
-        Key4 => [
-            'Value',
-            'Value',
-            {
-                Key5 => 'Value',
-            },
-        ],
-    },
-};
-$Sort = [                                  # wrapper for level 1
-    {                                      # first entry for level 1
-        Key2 => [                          # wrapper for level 2
-            {                              # first entry for level 2
-                Key4 => [
-                    undef,
-                    undef,
-                    [                      # wrapper for level 3
-                        {
-                            Key5 => undef, # first entry for level 3
-                        },
-                    ],                     # wrapper for level 3
-                ],
-            },                             # first entry for level 2
-            {                              # second entry for level 2
-                Key3 => undef,
-            },                             # second entry for level 2
-        ],                                 # wrapper for level 2
-    }                                      # first entry for level 1
-    {                                      # second entry for level 1
-        Key1 => undef,
-    }                                      # second entry for level 1
-];                                         # wrapper for level 1
+
+    $Data = {
+        Key1 => 'Value',
+        Key2 => {
+            Key3 => 'Value',
+            Key4 => [
+                'Value',
+                'Value',
+                {
+                    Key5 => 'Value',
+                },
+            ],
+        },
+    };
+
+    $Sort = [                                  # wrapper for level 1
+        {                                      # first entry for level 1
+            Key2 => [                          # wrapper for level 2
+                {                              # first entry for level 2
+                    Key4 => [
+                        undef,
+                        undef,
+                        [                      # wrapper for level 3
+                            {
+                                Key5 => undef, # first entry for level 3
+                            },
+                        ],                     # wrapper for level 3
+                    ],
+                },                             # first entry for level 2
+                {                              # second entry for level 2
+                    Key3 => undef,
+                },                             # second entry for level 2
+            ],                                 # wrapper for level 2
+        }                                      # first entry for level 1
+        {                                      # second entry for level 1
+            Key1 => undef,
+        }                                      # second entry for level 1
+    ];                                         # wrapper for level 1
 
     my $Result = $TransportObject->_SOAPOutputRecursion(
         Data => {           # data payload
@@ -1658,14 +1660,14 @@ sub _SOAPOutputTypesGet {
             my @SortArrayElementKeys = sort keys %{$SortArrayElement};
             if ( scalar @SortArrayElementKeys != 1 ) {
                 return {
-                    Success => 0,
+                    Success      => 0,
                     ErrorMessage =>
                         'Sort array element hash reference must contain exactly one key/value pair',
                 };
             }
             if ( !IsStringWithData( $SortArrayElementKeys[0] ) ) {
                 return {
-                    Success => 0,
+                    Success      => 0,
                     ErrorMessage =>
                         'Key of sort array element hash reference must be a non zero-length string',
                 };
