@@ -772,6 +772,13 @@ sub Run {
             );
         }
 
+        # this is a workaround to have initial empty queue
+        # value or initial queue value without a close button
+        # depending if queue was configured or passed in the parameter
+        # without this first possible queue would always be selected
+        # '||-' means empty value of a queue
+        my $DestPossibleNone = $Dest && $Dest ne '||-' ? 0 : 1;
+
         my $JSON = $LayoutObject->BuildSelectionJSON(
             [
                 {
@@ -779,7 +786,7 @@ sub Run {
                     Data         => $NewTos,
                     SelectedID   => $Dest,
                     Translation  => 0,
-                    PossibleNone => 1,
+                    PossibleNone => $DestPossibleNone,
                     TreeView     => $TreeView,
                     Max          => 100,
                 },
@@ -966,8 +973,11 @@ sub _MaskNew {
 
     if ( $Config->{Queue} ) {
 
+        my $SelectedDest     = $Param{ToSelected} || $Param{QueueID};
+        my $DestPossibleNone = 1;
+
         # check own selection
-        my %NewTos = ( '', '-' );
+        my %NewTos;
         my $Module = $ConfigObject->Get('CustomerPanel::NewTicketQueueSelectionModule')
             || 'Kernel::Output::HTML::CustomerNewTicket::QueueSelectionGeneric';
         if ( $Kernel::OM->Get('Kernel::System::Main')->Require($Module) ) {
@@ -989,8 +999,19 @@ sub _MaskNew {
                     Env       => $Self,
                     ACLParams => \%Param
                 ),
-                ( '', => '-' )
             );
+
+            # this is a workaround to have initial empty queue
+            # value or initial queue value without a close button
+            # depending if queue was configured or passed in the parameter
+            # without this first possible queue would always be selected
+            # '||-' means empty value of a queue
+            if ( $SelectedDest && $SelectedDest ne '||-' ) {
+                $DestPossibleNone = 0;
+            }
+            else {
+                $NewTos{''} = '-';
+            }
         }
         else {
             return $LayoutObject->FatalError();
@@ -1004,13 +1025,14 @@ sub _MaskNew {
             }
         }
         $Param{ToStrg} = $LayoutObject->AgentQueueListOption(
-            Data       => \%NewTos,
-            Multiple   => 0,
-            Size       => 0,
-            Name       => 'Dest',
-            Class      => "Validate_Required Modernize " . $Param{Errors}->{QueueInvalid},
-            SelectedID => $Param{ToSelected} || $Param{QueueID},
-            TreeView   => $TreeView,
+            Data         => \%NewTos,
+            Multiple     => 0,
+            Size         => 0,
+            PossibleNone => $DestPossibleNone,
+            Name         => 'Dest',
+            Class        => "Validate_Required Modernize " . $Param{Errors}->{QueueInvalid},
+            SelectedID   => $SelectedDest,
+            TreeView     => $TreeView,
         );
         $Param{RenderTeamData} = 1;
         $LayoutObject->Block(
