@@ -11,25 +11,26 @@ package Kernel::Output::HTML::TicketOverview::Small;
 
 use strict;
 use warnings;
+use utf8;
 
 use Kernel::System::VariableCheck qw(:all);
-use Kernel::Language qw(Translatable);
+use Kernel::Language              qw(Translatable);
 
 our @ObjectDependencies = (
     'Kernel::Config',
     'Kernel::Language',
-    'Kernel::System::Log',
     'Kernel::Output::HTML::Layout',
     'Kernel::System::CustomerUser',
-    'Kernel::System::Group',
-    'Kernel::System::User',
-    'Kernel::System::JSON',
     'Kernel::System::DynamicField',
-    'Kernel::System::Ticket::ColumnFilter',
     'Kernel::System::DynamicField::Backend',
+    'Kernel::System::Group',
+    'Kernel::System::JSON',
+    'Kernel::System::Log',
+    'Kernel::System::Main',
     'Kernel::System::Ticket',
     'Kernel::System::Ticket::Article',
-    'Kernel::System::Main',
+    'Kernel::System::Ticket::ColumnFilter',
+    'Kernel::System::User',
 );
 
 sub new {
@@ -541,23 +542,27 @@ sub Run {
                     sort keys %Actions;
             }
 
-            my $ACL = $TicketObject->TicketAcl(
-                Data          => \%PossibleActions,
-                Action        => $Self->{Action},
-                TicketID      => $Article{TicketID},
-                ReturnType    => 'Action',
-                ReturnSubType => '-',
-                UserID        => $Self->{UserID},
-            );
             my %AclAction = %PossibleActions;
-            if ($ACL) {
-                %AclAction = $TicketObject->TicketAclActionData();
-            }
 
             # run ticket pre menu modules
             my @ActionItems;
             if ( ref $ConfigObject->Get('Ticket::Frontend::PreMenuModule') eq 'HASH' ) {
                 my %Menus = %{ $ConfigObject->Get('Ticket::Frontend::PreMenuModule') };
+
+                if (%Menus) {
+                    my $ACL = $TicketObject->TicketAcl(
+                        Data          => \%PossibleActions,
+                        Action        => $Self->{Action},
+                        TicketID      => $Article{TicketID},
+                        ReturnType    => 'Action',
+                        ReturnSubType => '-',
+                        UserID        => $Self->{UserID},
+                    );
+                    if ($ACL) {
+                        %AclAction = $TicketObject->TicketAclActionData();
+                    }
+                }
+
                 my @Items;
                 MENU:
                 for my $Menu ( sort keys %Menus ) {
@@ -829,8 +834,8 @@ sub Run {
                     Data => {
                         %Param,
                         OrderBy              => $OrderBy,
-                        ColumnName           => $Column || '',
-                        CSS                  => $CSS || '',
+                        ColumnName           => $Column         || '',
+                        CSS                  => $CSS            || '',
                         ColumnNameTranslated => $TranslatedWord || $Column,
                         Title                => $Title,
                     },
@@ -1703,6 +1708,7 @@ sub Run {
                         Name => 'RecordDynamicFieldLink',
                         Data => {
                             Value                       => $ValueStrg->{Value},
+                            ValueKey                    => $Value,
                             Title                       => $ValueStrg->{Title},
                             Link                        => $ValueStrg->{Link},
                             $DynamicFieldConfig->{Name} => $ValueStrg->{Title},
@@ -1919,6 +1925,7 @@ sub _InitialColumnFilter {
         Class       => $Class . ' Modernize',
         Translation => $TranslationOption,
         SelectedID  => '',
+        TreeView    => 1,
     );
     return $ColumnFilterHTML;
 }
@@ -2026,7 +2033,7 @@ sub _ColumnFilterJSON {
     my $Data = [
         {
             Key   => 'DeleteFilter',
-            Value => uc $Label,
+            Value => '-',
         },
         {
             Key      => '-',
